@@ -33,8 +33,8 @@ SB_MULTIPLIER = {
     f'2022-{EXPANDED_ALIAS}': 1.0,
 }
 MAX_IN_GAME_SPD = {
-    '2000': 20,
-    '2001': 20,
+    '2000': 25,
+    '2001': 25,
     '2002': 27,
     '2003': 27,
     '2004': 27,
@@ -327,9 +327,9 @@ OB_COMBOS = {
         [4,5],
         [5,2],[5,3],[5,4],[5,5],
         [6,2],[6,3],[6,4],[6,5],
-        [7,2],[7,3],[7,4],[7,5],
-        [8,2],[8,3],[8,4],[8,5],
-        [9,2],[9,3],[9,4],[9,5],
+        [7,3],[7,4],[7,5],
+        [8,3],[8,4],[8,5],
+        [9,3],[9,4],[9,5],
         [10,2],[10,3],[10,4],[10,5],
         [11,2],[11,3],
         [12,0],[12,2],[12,3]
@@ -420,8 +420,8 @@ CONTROL_COMBOS = {
         [2,15],[2,16],
         [3,15],[3,16],[3,17],[3,18],
         [4,14],[4,15],[4,16],[4,17],[4,18],
-        [5,15],[5,16],[5,17],[5,18],
-        [6,15],[6,16],[6,17],[6,18]
+        [5,15],[5,16],[5,17],[5,18],[5,19],
+        [6,15],[6,16],[6,17],[6,18],[6,20],
     ],
     '2001':[
         [0,17],[0,18],
@@ -430,7 +430,7 @@ CONTROL_COMBOS = {
         [3,14],[3,15],[3,16],[3,17],
         [4,14],[4,15],[4,16],[4,17],
         [5,14],[5,15],[5,16],[5,17],[5,18],[5,19],
-        [6,14],[6,15],[6,16],[6,17],[6,18],
+        [6,14],[6,15],[6,16],[6,17],[6,18],[6,20],
     ],
     '2002':[
         [1,15],[1,16],[1,17],[1,18],
@@ -438,7 +438,7 @@ CONTROL_COMBOS = {
         [3,15],[3,16],[3,17],[3,18],[3,19],
         [4,14],[4,15],[4,16],[4,17],[4,18],[4,19],
         [5,15],[5,16],[5,17],[5,18],
-        [6,16],[6,17],[6,18]
+        [6,16],[6,17],[6,18],[6,20],
     ],
     '2003':[
         [1,15],[1,16],
@@ -446,7 +446,7 @@ CONTROL_COMBOS = {
         [3,14],[3,15],[3,16],
         [4,14],[4,15],[4,16],[4,17],
         [5,15],[5,16],[5,17],[5,18],
-        [6,16],[6,17],[6,18]
+        [6,16],[6,17],[6,18],[6,20],
     ],
     '2004':[
         [1,13],[1,14],[1,15],[1,16],
@@ -454,7 +454,7 @@ CONTROL_COMBOS = {
         [3,15],[3,16],[3,17],
         [4,14],[4,16],[4,17],
         [5,12],[5,15],[5,16],[5,17],[5,18],[5,19],
-        [6,15],[6,16],[6,17],[6,18]
+        [6,15],[6,16],[6,17],[6,18],[6,20],
     ],
     '2005':[
         [1,14],[1,15],[1,16],
@@ -462,7 +462,7 @@ CONTROL_COMBOS = {
         [3,15],[3,16],[3,17],
         [4,16],[4,17],
         [5,16],[5,17],[5,18],[5,19],
-        [6,15],[6,16],[6,17],[6,18]
+        [6,15],[6,16],[6,17],[6,18],[6,20],
     ],
     f'2022-{CLASSIC_ALIAS}': [
         [0,17],[0,18],
@@ -471,7 +471,7 @@ CONTROL_COMBOS = {
         [3,14],[3,15],[3,16],[3,17],[3,18],[3,19],
         [4,14],[4,15],[4,16],[4,17],[4,18],
         [5,14],[5,15],[5,16],[5,17],[5,18],[5,19],
-        [6,14],[6,15],[6,16],[6,17],[6,18],
+        [6,14],[6,15],[6,16],[6,17],[6,18],[6,20],
     ],
     f'2022-{EXPANDED_ALIAS}': [
         [1,14],[1,15],[1,16],[1,17],[1,18],
@@ -479,7 +479,7 @@ CONTROL_COMBOS = {
         [3,15],[3,16],[3,17],[3,18],
         [4,16],[4,17],[4,18],[4,19],
         [5,16],[5,17],[5,18],[5,19],
-        [6,15],[6,16],[6,17],[6,18]
+        [6,15],[6,16],[6,17],[6,18],[6,20],
     ],
 }
 
@@ -1996,7 +1996,7 @@ IMAGE_LOCATIONS = {
         '2022': (1161,1375),
     },
     'player_name': {
-        '2000': (150,0),
+        '2000': (150,-1225),
         '2001': (105,0),
         '2002': (1275,0),
         '2003': (1365,0),
@@ -2005,7 +2005,7 @@ IMAGE_LOCATIONS = {
         '2022': (325,1575),
     },
     'player_name_small': {
-        '2000': (160,0),
+        '2000': (165,-1225),
         '2001': (105,0),
         '2002': (1285,0),
         '2003': (1375,0),
@@ -2037,14 +2037,14 @@ IMAGE_LOCATIONS = {
         '2000': (129,2016),
         '2001': (129,2016),
         '2002': (60,1860),
-        '2003': (83,1785),
+        '2003': (93,1785),
         '2004': (1344,1911),
         '2005': (1344,1911),
         '2022': (1200,2020),
     },
     'number': {
         '2002': (120,1785),
-        '2003': (113,1785),
+        '2003': (116,1785),
         '2004': (1191,1911),
         '2005': (1191,1911),
         '2022': (1000,2020),
@@ -2067,6 +2067,24 @@ IMAGE_LOCATIONS = {
         '2005': (135,90),
         '2022': (133,252),
     },
+    'rookie_season': {
+        '2000': (1200,1086),
+        '2001': (1108,1040),
+        '2002': (80,1360),
+        '2003': (1085,1025),
+        '2004': (1100,1400),
+        '2005': (1100,1400),
+        '2022': (1075,1340),
+    },
+    'rookie_season_year_text': {
+        '2000': (40, 145),
+        '2001': (40, 145),
+        '2002': (40, 145),
+        '2003': (40, 145),
+        '2004': (40, 145),
+        '2005': (40, 145),
+        '2022': (40, 145),
+    },
     'version': {
         '2000': (1360,2050),
         '2001': (1360,2050),
@@ -2119,7 +2137,7 @@ IMAGE_SIZES = {
         '2022': (275,275),
     },
     'player_name': {
-        '2000': (3300, 300),
+        '2000': (2100, 300),
         '2001': (1545, 300),
         '2002': (1395, 300),
         '2003': (3300, 300),
@@ -2135,6 +2153,15 @@ IMAGE_SIZES = {
         '2004': (339,522),
         '2005': (339,522),
         '2022': (380,380),
+    },
+    'rookie_season': {
+        '2000': (273,273),
+        '2001': (300,300),
+        '2002': (575,575),
+        '2003': (375,375),
+        '2004': (339,339),
+        '2005': (339,339),
+        '2022': (380,380),
     }
 }
 
